/*
 * Ibis - IRCv3 Library
 * Copyright (C) 2022-2024 Ibis Developers
 *
 * Ibis is the legal property of its developers, whose names are too numerous
 * to list here.  Please refer to the COPYRIGHT file distributed with this
 * source distribution.
 *
 * This library is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this library; if not, see <https://www.gnu.org/licenses/>.
 */

#if !defined(IBIS_GLOBAL_HEADER_INSIDE) && !defined(IBIS_COMPILATION)
# error "only <ibis.h> may be included directly"
#endif

#ifndef IBIS_NORMALIZE_H
#define IBIS_NORMALIZE_H

#include <glib.h>

#include "ibisversion.h"

G_BEGIN_DECLS

/**
 * ibis_normalize_ascii:
 * @input: (nullable): the input to normalize
 *
 * Normalizes @input, i.e., it converts all uppercase letters in @input to their
 * lowercase equivalents.
 *
 * Returns: (transfer full): A normalized copy of @input.
 *
 * Since: 0.7
 */
IBIS_AVAILABLE_IN_0_7
char *ibis_normalize_ascii(const char *input);

/**
 * ibis_normalize_rfc1459:
 * @input: (nullable): the input to normalize
 *
 * Normalizes @input, i.e., it converts all uppercase letters in @input to their
 * lowercase equivalents with the addition of the characters '[', ']', '\',
 * and '~'.
 *
 * The lowercase equivalents of the characters '[', ']', '\', and '~' are
 * {', '}', '|', and '^' respectively.
 *
 * Returns: (transfer full): A normalized copy of @input.
 *
 * Since: 0.7
 */
IBIS_AVAILABLE_IN_0_7
char *ibis_normalize_rfc1459(const char *input);

/**
 * ibis_normalize_rfc1459_strict:
 * @input: (nullable): the input to normalize
 *
 * Normalizes @input, i.e., it converts all uppercase letters in @input to their
 * lowercase equivalents with the addition of the characters '[', ']', and '\'.
 *
 * The lowercase equivalents of the characters '[', ']', and '\', are
 * {', '}', and '|' respectively.
 *
 * Returns: (transfer full): A normalized copy of @input.
 *
 * Since: 0.7
 */
IBIS_AVAILABLE_IN_0_7
char *ibis_normalize_rfc1459_strict(const char *input);

G_END_DECLS

#endif /* IBIS_NORMALIZE_H */
